AuthorizationSelector

Struct AuthorizationSelector 

pub struct AuthorizationSelector(pub [u8; 4]);
A 4-byte authorization selector used to identify authwit request types.

Tuple Fields

0: [u8; 4]

Implementations

Source

impl AuthorizationSelector

pub fn from_hex(value: &str) -> Result<Self, Error>

Parse an authorization selector from a hex string.

pub fn from_field(field: Fr) -> Self

Convert a field element to an authorization selector using its low 32 bits.

pub fn from_signature(signature: &str) -> Self

Compute an authorization selector from an authorization signature.

pub fn to_field(self) -> Fr

Convert this selector to its field representation.