Module constants

Module constants 

Well-known protocol contract addresses and domain separators.

These addresses and constants are deterministic and identical across all Aztec networks.

Modules

domain_separator
Domain separators used in Poseidon2 hashing throughout the protocol.
protocol_contract_address
Well-known protocol contract addresses.

Constants

ARTIFACT_FUNCTION_TREE_MAX_HEIGHT
Maximum height of the artifact function tree.
FUNCTION_TREE_HEIGHT
Size constants for deployment computations. Height of the private functions Merkle tree.
MAX_PACKED_PUBLIC_BYTECODE_SIZE_IN_FIELDS
Maximum number of field elements in packed public bytecode.
MAX_PROCESSABLE_L2_GAS
Maximum processable L2 gas for a transaction.

Functions

contract_class_registry_bytecode_capsule_slot
Bytecode capsule slot used by the Contract Class Registry.