pub fn compute_private_functions_root_from_artifact(
artifact: &ContractArtifact,
) -> Result<Fr, Error>Expand description
Extract private functions from an artifact and compute the root.
pub fn compute_private_functions_root_from_artifact(
artifact: &ContractArtifact,
) -> Result<Fr, Error>Extract private functions from an artifact and compute the root.