compute_protocol_contracts_hash

Function compute_protocol_contracts_hash 

pub fn compute_protocol_contracts_hash() -> Fr
Compute the protocol contracts hash from the known protocol contract addresses.

Mirrors TS ProtocolContractAddress.computeProtocolContractsHash() which hashes the five canonical protocol contract addresses (1..5) with Poseidon2.