pub struct Tx {
pub data: PrivateKernelTailCircuitPublicInputs,
pub chonk_proof: ChonkProof,
pub contract_class_log_fields: Vec<ContractClassLogFields>,
pub public_function_calldata: Vec<HashedValues>,
}Expand description
Node-facing transaction envelope matching the upstream stdlib Tx JSON shape.
Fields
data: PrivateKernelTailCircuitPublicInputsPrivate kernel tail public inputs, serialized as a stdlib buffer.
chonk_proof: ChonkProofChonk proof, serialized as a stdlib buffer.
contract_class_log_fields: Vec<ContractClassLogFields>Contract-class log preimages corresponding to the log hashes in data.
public_function_calldata: Vec<HashedValues>Calldata preimages for enqueued public calls.
Implementations