Module validation

Module validation 

Transaction validation logic matching the node’s DataTxValidator.

These functions implement the same invariant checks as the upstream p2p/src/msg_validators/tx_validator/data_validator.ts.

Functions

validate_calldata
Validate the calldata in a typed transaction.
validate_contract_class_logs
Validate the contract class logs in a typed transaction.