pub fn validate_contract_class_logs(
public_inputs: &PrivateKernelTailPublicInputs,
log_fields: &[ContractClassLogFields],
) -> Result<(), Error>Expand description
Validate the contract class logs in a typed transaction.
Checks:
- number of log fields entries matches log hashes in public inputs
- each log hash matches the hash of its corresponding fields