Skip to main contentModule abi
Source - AbiParameter
- A named, typed parameter in a function ABI.
- ContractArtifact
- A deserialized contract artifact containing function metadata.
- EventSelector
- A field-element event selector used to identify contract events.
- FunctionArtifact
- Metadata for a single function within a contract artifact.
- FunctionSelector
- A 4-byte function selector used to identify contract functions.
- AbiType
- ABI type representation for function parameters and return values.
- AbiValue
- A concrete ABI value used as a function argument or return value.
- FunctionType
- The type of a contract function.