pub struct AuthorizationSelector(pub [u8; 4]);Expand description
A 4-byte authorization selector used to identify authwit request types.
Tuple Fields
0: [u8; 4]Implementations
Sourceimpl AuthorizationSelector
impl AuthorizationSelector
Sourcepub fn from_hex(value: &str) -> Result<Self, Error>
pub fn from_hex(value: &str) -> Result<Self, Error>
Parse an authorization selector from a hex string.
Sourcepub fn from_field(field: Fr) -> Self
pub fn from_field(field: Fr) -> Self
Convert a field element to an authorization selector using its low 32 bits.
Sourcepub fn from_signature(signature: &str) -> Self
pub fn from_signature(signature: &str) -> Self
Compute an authorization selector from an authorization signature.