pub struct ContractArtifact {
pub name: String,
pub functions: Vec<FunctionArtifact>,
pub outputs: Option<Value>,
pub file_map: Option<Value>,
}Expand description
A deserialized contract artifact containing function metadata.
Fields
name: StringContract name.
functions: Vec<FunctionArtifact>Functions defined in the contract.
outputs: Option<Value>Compiler output metadata (opaque JSON).
file_map: Option<Value>Source file map (opaque JSON).
Implementations
Sourceimpl ContractArtifact
impl ContractArtifact
Sourcepub fn from_json(json: &str) -> Result<Self, Error>
pub fn from_json(json: &str) -> Result<Self, Error>
Deserialize a contract artifact from a JSON string.
Sourcepub fn find_function(&self, name: &str) -> Result<&FunctionArtifact, Error>
pub fn find_function(&self, name: &str) -> Result<&FunctionArtifact, Error>
Find a function by name, returning an error if not found.
Sourcepub fn find_function_by_type(
&self,
name: &str,
function_type: &FunctionType,
) -> Result<&FunctionArtifact, Error>
pub fn find_function_by_type( &self, name: &str, function_type: &FunctionType, ) -> Result<&FunctionArtifact, Error>
Find a function by name and type, returning an error if not found.