pub struct FunctionArtifact {
pub name: String,
pub function_type: FunctionType,
pub is_initializer: bool,
pub is_static: bool,
pub parameters: Vec<AbiParameter>,
pub return_types: Vec<AbiType>,
pub selector: Option<FunctionSelector>,
}Expand description
Metadata for a single function within a contract artifact.
Fields
name: StringFunction name.
function_type: FunctionTypeWhether this is a private, public, or utility function.
is_initializer: boolWhether this function is a contract initializer (constructor).
is_static: boolWhether this function is a static (read-only) call.
parameters: Vec<AbiParameter>Function parameters.
return_types: Vec<AbiType>Return types.
selector: Option<FunctionSelector>Pre-computed function selector.